@@ -19,6 +19,7 @@ from common_wrangler.common import (InvalidDataError, warning, RG, KB, H, EHPART
                                     GOOD_RET, INPUT_ERROR, IO_ERROR, INVALID_DATA,
                                     write_csv, create_out_fname, make_fig, parse_stoich, capture_stdout, list_to_file,
                                     round_sig_figs)
+from gaussian_wrangler import __version__
 
 __author__ = 'hmayes'
 
@@ -348,20 +349,23 @@ def check_gausslog_fileset(file_set, good_vibes_check, results_dict):
                         format(gauss_ver, file_gauss_ver, file_set))
 
     # Now overall checks
+    file_set_str = "\n              ".join([""] + [os.path.relpath(f) for f in file_set])
     if len(ts_stoich_dict) > 0:
         if react_stoich_dict != ts_stoich_dict:
             raise InvalidDataError("Check stoichiometries of reactant(s) and transition state for set: {}\n"
-                                   "reactants: {}, products: {}".format(file_set, react_stoich_dict, ts_stoich_dict))
+                                   "reactants: {}, products: {}".format(file_set_str, react_stoich_dict,
+                                                                        ts_stoich_dict))
         if total_react_charge != ts_charge:
             raise InvalidDataError("Check charge of reactant(s) and transition state for set: {}\n"
-                                   "Found {} and {}, respectively".format(file_set, total_react_charge, ts_charge))
+                                   "Found {} and {}, respectively".format(file_set_str, total_react_charge, ts_charge))
     if len(prod_stoich_dict) > 0:
         if react_stoich_dict != prod_stoich_dict:
             raise InvalidDataError("Check stoichiometries of reactant(s) and product(s) for set: {}\n"
-                                   "reactants: {}, products: {}".format(file_set, react_stoich_dict, prod_stoich_dict))
+                                   "reactants: {}, products: {}".format(file_set_str, react_stoich_dict,
+                                                                        prod_stoich_dict))
         if total_react_charge != total_product_charge:
             raise InvalidDataError("Check charge of reactant(s) and product(s) for set: {}\nFound {} and {}, "
-                                   "respectively".format(file_set, total_react_charge, total_product_charge))
+                                   "respectively".format(file_set_str, total_react_charge, total_product_charge))
 
     mult_check = np.sum(multiplicities - multiplicities[0])
     if mult_check != 0:
@@ -607,6 +611,7 @@ def process_file_set(file_set, options, print_mode, results_dict, tog_fname):
 
 
 def main(argv=None):
+    print(f"Running GaussianWrangler script goodvibes_helper version {__version__}")
     # Read input
     args, ret = parse_cmdline(argv)
     if ret != GOOD_RET or args is None:
